==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/app/translations/qmmp_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Não limpar lista de reprodução</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Iniciar reprodução da faixa atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pausa na faixa atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pausa se em reprodução, ou reproduzir</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Parar faixa atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Mostrar diálogo Ir para o ficheiro</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Definir o volume de reprodução (exemplo: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation>Silenciar/Restaurar volume</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Avançar na lista de reprodução</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Recuar na lista de reprodução</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Mostrar/Ocultar aplicação</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation>Mostrar janela principal</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Mostrar diálogo Adicionar ficheiro</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Mostrar diálogo Adicionar diretório</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="95"/>
        <source>Unknown command</source>
        <translation>Comando desconhecido</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="350"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Utilização: qmmp [opções] [ficheiros]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="351"/>
        <source>Options:</source>
        <translation>Opções:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="355"/>
        <source>Don&apos;t start the application</source>
        <translation>Não iniciar a aplicação</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="356"/>
        <source>Display this text and exit</source>
        <translation>Mostrar este texto e sair</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="357"/>
        <source>Print version number and exit</source>
        <translation>Mostrar número da versão e sair</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="358"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Envie ideias, correções e relatórios de erro para forkotov02@hotmail.ru</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="361"/>
        <source>Command Line Help</source>
        <translation>Ajuda para linha de comandos</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="374"/>
        <source>QMMP version: %1</source>
        <translation>Versão Qmmp: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="375"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Compilado com Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="376"/>
        <source>Using Qt version: %1</source>
        <translation>Utiliza a versão Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="379"/>
        <source>Qmmp Version</source>
        <translation>Versão Qmmp</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/app/translations/qmmp_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Não limpar lista de reprodução</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Iniciar reprodução da faixa atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pausa na faixa atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pausa se em reprodução, ou reproduzir</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Parar faixa atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Mostrar diálogo Ir para o ficheiro</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Definir o volume de reprodução (exemplo: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Imprimir nível de volume</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Silenciar/Restaurar volume</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Imprimir estado de silêncio</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Avançar na lista de reprodução</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Recuar na lista de reprodução</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Mostrar/Ocultar aplicação</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Mostrar janela principal</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Mostrar diálogo Adicionar ficheiro</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Mostrar diálogo Adicionar diretório</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="109"/>
        <source>Unknown command</source>
        <translation>Comando desconhecido</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="373"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Utilização: qmmp [opções] [ficheiros]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="374"/>
        <source>Options:</source>
        <translation>Opções:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="380"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Inicia o qmmp com a interface especificada</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="381"/>
        <source>List all available user interfaces</source>
        <translation>Lista todas as interfaces disponíveis</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="382"/>
        <source>Don&apos;t start the application</source>
        <translation>Não iniciar a aplicação</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="383"/>
        <source>Display this text and exit</source>
        <translation>Mostrar este texto e sair</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="384"/>
        <source>Print version number and exit</source>
        <translation>Mostrar número da versão e sair</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="386"/>
        <source>Home page: %1</source>
        <translation>Página web: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="387"/>
        <source>Development page: %1</source>
        <translation>Página de desenvolvimento: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="388"/>
        <source>Bug tracker: %1</source>
        <translation>Reporte de erros: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="393"/>
        <source>Command Line Help</source>
        <translation>Ajuda para linha de comandos</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="406"/>
        <source>QMMP version: %1</source>
        <translation>Versão Qmmp: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="407"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Compilado com Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="408"/>
        <source>Using Qt version: %1</source>
        <translation>Utiliza a versão Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="411"/>
        <source>Qmmp Version</source>
        <translation>Versão Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="428"/>
        <source>User Interfaces</source>
        <translation>Interface de utilizador</translation>
    </message>
</context>
</TS>
